==> apache-jena_4.5.0.orig.tar.gz: jena-jena-4.5.0/jena-base/src/main/java/org/apache/jena/atlas/iterator/IteratorInteger.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.atlas.iterator;

import java.util.Iterator ;

public class IteratorInteger implements Iterator<Long>
{
    private final long start ;
    private final long finish ;
    private long current ;

    public static IteratorInteger range(long start, long finish)
    {
        return new IteratorInteger(start, finish) ;
    }


    /** [start, finish) */
    public IteratorInteger(long start, long finish)
    {
        this.start = start ;
        this.finish = finish ;
        this.current = start ;
    }

    @Override
    public boolean hasNext()
    {
        return ( current < finish ) ;
    }

    @Override
    public Long next()
    {
        Long v = current;
        current++ ;
        return v ;
    }
}

==> apache-jena_4.9.0.orig.tar.gz: jena-jena-4.9.0/jena-base/src/main/java/org/apache/jena/atlas/iterator/IteratorInteger.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.jena.atlas.iterator;

import java.util.Iterator ;
import java.util.function.Consumer;

public class IteratorInteger implements Iterator<Long>
{
    private final long start ;
    private final long finish ;
    private long current ;

    public static IteratorInteger range(long start, long finish)
    {
        return new IteratorInteger(start, finish) ;
    }


    /** [start, finish) */
    public IteratorInteger(long start, long finish)
    {
        this.start = start ;
        this.finish = finish ;
        this.current = start ;
    }

    @Override
    public boolean hasNext()
    {
        return ( current < finish ) ;
    }

    @Override
    public Long next()
    {
        return current++;
    }

    @Override
    public void forEachRemaining(Consumer<? super Long> action) {
        while (current < finish) {
            action.accept(current);
            current++;
        }
    }
}
